
Cookiecutter Hypermodern Python Instance
========================================

|Tests| |Codecov| |PyPI| |Python Version| |Read the Docs| |License| |Black| |pre-commit| |Dependabot|

.. |Tests| image:: https://github.com/cjolowicz/cookiecutter-hypermodern-python-instance/workflows/Tests/badge.svg
   :target: https://github.com/cjolowicz/cookiecutter-hypermodern-python-instance/actions?workflow=Tests
   :alt: Tests
.. |Codecov| image:: https://codecov.io/gh/cjolowicz/cookiecutter-hypermodern-python-instance/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/cjolowicz/cookiecutter-hypermodern-python-instance
   :alt: Codecov
.. |PyPI| image:: https://img.shields.io/pypi/v/cookiecutter-hypermodern-python-instance.svg
   :target: https://pypi.org/project/cookiecutter-hypermodern-python-instance/
   :alt: PyPI
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/cookiecutter-hypermodern-python-instance
   :target: https://pypi.org/project/cookiecutter-hypermodern-python-instance
   :alt: Python Version
.. |Read the Docs| image:: https://readthedocs.org/projects/cookiecutter-hypermodern-python-instance/badge/
   :target: https://cookiecutter-hypermodern-python-instance.readthedocs.io/
   :alt: Read the Docs
.. |License| image:: https://img.shields.io/pypi/l/cookiecutter-hypermodern-python-instance
   :target: https://opensource.org/licenses/MIT
   :alt: License
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit
.. |Dependabot| image:: https://api.dependabot.com/badges/status?host=github&repo=cjolowicz/cookiecutter-hypermodern-python-instance
   :target: https://dependabot.com
   :alt: Dependabot


Features
--------

* TODO


Requirements
------------

* TODO


Installation
------------

You can install *Cookiecutter Hypermodern Python Instance* via pip_ from PyPI_:

.. code:: console

   $ pip install cookiecutter-hypermodern-python-instance


Usage
-----

* TODO


Contributing
------------

Contributions are very welcome.
To learn more, see the `Contributor Guide`_.


License
-------

Distributed under the terms of the MIT_ license,
*Cookiecutter Hypermodern Python Instance* is free and open source software.


Issues
------

If you encounter any problems,
please `file an issue`_ along with a detailed description.


Credits
-------

This project was generated from `@cjolowicz`_'s `Hypermodern Python Cookiecutter`_ template.


.. _@cjolowicz: https://github.com/cjolowicz
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _MIT: http://opensource.org/licenses/MIT
.. _PyPI: https://pypi.org/
.. _Hypermodern Python Cookiecutter: https://github.com/cjolowicz/cookiecutter-hypermodern-python
.. _file an issue: https://github.com/cjolowicz/cookiecutter-hypermodern-python-instance/issues
.. _pip: https://pip.pypa.io/
.. github-only
.. _Contributor Guide: CONTRIBUTING.rst
